@@ -3,11 +3,11 @@
 
 =head1 NAME
 
-RDF::Trine::Parser::NTriples - N-Triples Parser.
+RDF::Trine::Parser::NTriples - N-Triples Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::NTriples version 0.123_01
+This document describes RDF::Trine::Parser::NTriples version 0.124_01
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.123_01';
+	$VERSION	= '0.124_01';
 	$RDF::Trine::Parser::parser_names{ 'ntriples' }	= __PACKAGE__;
 	foreach my $type (qw(text/plain)) {
 		$RDF::Trine::Parser::media_types{ $type }	= __PACKAGE__;
@@ -126,7 +126,7 @@ LINE:
 		};
 		$line	=~ s/^\s//g;
 		unless ($line eq '.') {
-# 			warn Dumper(\@nodes, $line);
+# 			Carp::cluck 'N-Triples parser failed: ' . Dumper(\@nodes, $line);
 			throw RDF::Trine::Error::ParserError -text => "Missing expected '.' at line $lineno";
 		}
 		
