@@ -3,11 +3,11 @@
 
 =head1 NAME
 
-RDF::Trine::Parser::RDFJSON - RDF/JSON RDF Parser.
+RDF::Trine::Parser::RDFJSON - RDF/JSON RDF Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::RDFJSON version 0.123_01
+This document describes RDF::Trine::Parser::RDFJSON version 0.124_01
 
 =head1 SYNOPSIS
 
@@ -41,7 +41,7 @@ use RDF::Trine qw(literal);
 use RDF::Trine::Statement;
 use RDF::Trine::Namespace;
 use RDF::Trine::Node;
-use RDF::Trine::Error;
+use RDF::Trine::Error qw(:try);
 
 use Scalar::Util qw(blessed looks_like_number);
 use JSON;
@@ -49,7 +49,7 @@ use JSON;
 our ($VERSION, $rdf, $xsd);
 our ($r_boolean, $r_comment, $r_decimal, $r_double, $r_integer, $r_language, $r_lcharacters, $r_line, $r_nameChar_extra, $r_nameStartChar_minus_underscore, $r_scharacters, $r_ucharacters, $r_booltest, $r_nameStartChar, $r_nameChar, $r_prefixName, $r_qname, $r_resource_test, $r_nameChar_test);
 BEGIN {
-	$VERSION				= '0.123_01';
+	$VERSION				= '0.124_01';
 	$RDF::Trine::Parser::parser_names{ 'rdfjson' }	= __PACKAGE__;
 	foreach my $type (qw(application/json application/x-rdf+json)) {
 		$RDF::Trine::Parser::media_types{ $type }	= __PACKAGE__;
@@ -123,7 +123,10 @@ sub parse {
 	my $handler	= shift;
 	my $opts	= shift;
 	
-	my $index = from_json($input, $opts);
+	my $index	= eval { from_json($input, $opts) };
+	if ($@) {
+		throw RDF::Trine::Error::ParserError -text => "$@";
+	}
 	
 	foreach my $s (keys %$index) {
 		my $ts = ( $s =~ /^_:(.*)$/ ) ?
