@@ -3,11 +3,11 @@
 
 =head1 NAME
 
-RDF::Trine::Serializer::RDFXML - RDF/XML Serializer.
+RDF::Trine::Serializer::RDFXML - RDF/XML Serializer
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::RDFXML version 0.123_01
+This document describes RDF::Trine::Serializer::RDFXML version 0.124_01
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.123_01';
+	$VERSION	= '0.124_01';
 	$RDF::Trine::Serializer::serializer_names{ 'rdfxml' }	= __PACKAGE__;
 	foreach my $type (qw(application/rdf+xml)) {
 		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
