@@ -4,7 +4,7 @@ RDF::Trine::Store::DBI - Persistent RDF storage based on DBI
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::DBI version 0.123_01
+This document describes RDF::Trine::Store::DBI version 0.124_01
 
 =head1 SYNOPSIS
 
@@ -47,8 +47,9 @@ use RDF::Trine::Store::DBI::Pg;
 
 our $VERSION;
 BEGIN {
-	$VERSION	= "0.123_01";
-	$RDF::Trine::Store::STORE_CLASSES{ __PACKAGE__ }	= $VERSION;
+	$VERSION	= "0.124_01";
+	my $class	= __PACKAGE__;
+	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 }
 
 ######################################################################
@@ -325,23 +326,26 @@ sub get_contexts {
 	my $sth		= $dbh->prepare( $sql );
 	$sth->execute();
 	my $sub		= sub {
-		my $row	= $sth->fetchrow_hashref;
-		return unless defined($row);
-		my $uri		= $self->_column_name( 'URI' );
-		my $name	= $self->_column_name( 'Name' );
-		my $value	= $self->_column_name( 'Value' );
-		if ($row->{ Context } == 0) {
-			return RDF::Trine::Node::Nil->new();
-		} elsif ($row->{ $uri }) {
-			return RDF::Trine::Node::Resource->new( $row->{ $uri } );
-		} elsif ($row->{ $name }) {
-			return RDF::Trine::Node::Blank->new( $row->{ $name } );
-		} elsif (defined $row->{ $value }) {
-			my @cols	= map { $self->_column_name( $_ ) } qw(Value Language Datatype);
-			return RDF::Trine::Node::Literal->new( @{ $row }{ @cols } );
-		} else {
-			return;
+		while (my $row = $sth->fetchrow_hashref) {
+			return unless defined($row);
+			my $uri		= $self->_column_name( 'URI' );
+			my $name	= $self->_column_name( 'Name' );
+			my $value	= $self->_column_name( 'Value' );
+			if ($row->{ Context } == 0) {
+				next;
+# 				return RDF::Trine::Node::Nil->new();
+			} elsif ($row->{ $uri }) {
+				return RDF::Trine::Node::Resource->new( $row->{ $uri } );
+			} elsif ($row->{ $name }) {
+				return RDF::Trine::Node::Blank->new( $row->{ $name } );
+			} elsif (defined $row->{ $value }) {
+				my @cols	= map { $self->_column_name( $_ ) } qw(Value Language Datatype);
+				return RDF::Trine::Node::Literal->new( @{ $row }{ @cols } );
+			} else {
+				return;
+			}
 		}
+		return;
 	};
 	return RDF::Trine::Iterator->new( $sub );
 }
