@@ -4,7 +4,7 @@ RDF::Trine::Store::Memory - Simple in-memory RDF store
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::Memory version 0.123_01
+This document describes RDF::Trine::Store::Memory version 0.124_01
 
 =head1 SYNOPSIS
 
@@ -36,8 +36,9 @@ use RDF::Trine::Error;
 my @pos_names;
 our $VERSION;
 BEGIN {
-	$VERSION	= "0.123_01";
-	$RDF::Trine::Store::STORE_CLASSES{ __PACKAGE__ }	= $VERSION;
+	$VERSION	= "0.124_01";
+	my $class	= __PACKAGE__;
+	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 	@pos_names	= qw(subject predicate object context);
 }
 
@@ -199,7 +200,7 @@ sub _get_statements_quad {
 			return unless ($i <= $#{ $self->{statements} });
 			my $st	= $self->{statements}[ $i ];
 # 			warn $st;
-			while (not(blessed($st))) {
+			while (not(blessed($st)) and ($i <= $#{ $self->{statements} })) {
 				$st	= $self->{statements}[ ++$i ];
 # 				warn "null st. next: $st";
 			}
@@ -283,7 +284,7 @@ the set of contexts of the stored quads.
 
 sub get_contexts {
 	my $self	= shift;
-	my @ctx		= values %{ $self->{ ctx_nodes } };
+	my @ctx		= grep { not($_->isa('RDF::Trine::Node::Nil')) } values %{ $self->{ ctx_nodes } };
  	return RDF::Trine::Iterator->new( \@ctx );
 }
 
